@@ -1,3 +1,4 @@
+# coding: utf-8
 from attest import AssertImportHook, COMPILES_AST
 from contextlib import contextmanager
 import django
@@ -6,6 +7,9 @@ import logging
 from pkg_resources import parse_version
 
 
+__all__ = ("testing_environment", )
+
+
 logger = logging.getLogger("django_attest")
 
 
@@ -13,7 +17,7 @@ if parse_version(django.get_version()) < parse_version('1.4'):
     logger.info("Django <1.4 has broken import infrastructure, Attest's"
                 " assert hook will be disabled.")
     AssertImportHook.disable()
-elif COMPILES_AST:
+elif COMPILES_AST and not AssertImportHook.enabled:
     AssertImportHook.enable()
 
 
@@ -22,14 +26,26 @@ def testing_environment():
     """
     Context manager to put Django into a state suitable for testing.
     """
-    # setup test environment
+    teardown = setup()
+    try:
+        yield
+    finally:
+        teardown()
+
+
+def setup():
+    """
+    Setup the environment for Django (create databases, turn on DEBUG, etc).
+
+    :returns: teardown function
+    """
+    # Use Django's test suite runner, as it sets up test databases nicely
     runner = DjangoTestSuiteRunner()
     runner.setup_test_environment()
     old_config = runner.setup_databases()
 
-    # do stuff
-    yield
+    def teardown():
+        runner.teardown_databases(old_config)
+        runner.teardown_test_environment()
 
-    # tear down environment
-    runner.teardown_databases(old_config)
-    runner.teardown_test_environment()
+    return teardown
